@@ -4,7 +4,8 @@
 #' @export
 unnest.tidyfit.models <- function(data, cols, ...) {
   class(data) <- class(data)[-1]
+  struc <- attr(data, "structure")
   df <- tidyr::unnest(data, {{cols}})
-  df <- tibble::new_tibble(df, class = "tidyfit.models")
+  df <- tibble::new_tibble(df, class = "tidyfit.models", structure = struc)
   return(df)
 }
