@@ -10,7 +10,7 @@ test_that("svm regression works", {
   expect_equal(nrow(predict(m_reg, df_reg)), 506)
   expect_equal(nrow(fitted(m_reg)), 506)
   expect_equal(nrow(resid(m_reg)), 506)
-  expect_equal(nrow(predict(m_reg, df_reg %>% select(-medv))), 506)
+  expect_equal(nrow(predict(m_reg, select(df_reg, -"medv"))), 506)
 
 })
 
@@ -22,7 +22,7 @@ test_that("svm classification works", {
   m_reg <- classify(df_cls3, Species ~ ., m("svm", cost = c(1)))
   expect_equal(nrow(predict(m_reg, df_cls3)), 450)
   expect_equal(nrow(fitted(m_reg)), 450)
-  expect_equal(nrow(predict(m_reg, df_cls3 %>% select(-Species))), 450)
+  expect_equal(nrow(predict(m_reg, df_cls3 %>% select(-"Species"))), 450)
 
 })
 
@@ -35,6 +35,6 @@ test_that("svm classification (2class) works", {
   expect_equal(nrow(coef(m_reg)), 5)
   expect_equal(nrow(predict(m_reg, df_cls2)), 100)
   expect_equal(nrow(fitted(m_reg)), 100)
-  expect_equal(nrow(predict(m_reg, df_cls2 %>% select(-Species))), 100)
+  expect_equal(nrow(predict(m_reg, df_cls2 %>% select(-"Species"))), 100)
 
 })
